# -*- coding: utf-8 -*-
"""
Building and running spiking neural networks using Intel's Loihi platform.

Currently, this code is part of the nxsdk, so we redirect there.
@author: rbodo
"""

# noinspection PyUnresolvedReferences
from nxsdk_modules_ncl.snntoolbox.nx_backend import SNN
